@@ -3,8 +3,7 @@ use cargo::CliResult;
 use cargo::GlobalContext;
 
 use cargo_c::build::cbuild;
-use cargo_c::cli::run_cargo_fallback;
-use cargo_c::cli::subcommand_install;
+use cargo_c::cli::{main_cli, run_cargo_fallback, subcommand_install};
 use cargo_c::config::global_context_configure;
 use cargo_c::install::cinstall;
 
@@ -12,10 +11,7 @@ fn main() -> CliResult {
     let mut config = GlobalContext::default()?;
 
     let subcommand = subcommand_install("cinstall", "Install the crate C-API");
-    let mut app = clap::command!()
-        .dont_collapse_args_in_usage(true)
-        .allow_external_subcommands(true)
-        .subcommand(subcommand);
+    let mut app = main_cli().subcommand(subcommand);
 
     let args = app.clone().get_matches();
 
