@@ -1,19 +1,15 @@
 use cargo::util::command_prelude::*;
 
 use cargo_c::build::*;
-use cargo_c::cli::run_cargo_fallback;
-use cargo_c::cli::subcommand_test;
+use cargo_c::cli::{main_cli, run_cargo_fallback, subcommand_test};
 use cargo_c::config::*;
 
 fn main() -> CliResult {
-    let mut config = Config::default()?;
+    let mut config = GlobalContext::default()?;
 
     let subcommand = subcommand_test("ctest");
 
-    let mut app = clap::command!()
-        .dont_collapse_args_in_usage(true)
-        .allow_external_subcommands(true)
-        .subcommand(subcommand);
+    let mut app = main_cli().subcommand(subcommand);
 
     let args = app.clone().get_matches();
 
@@ -34,11 +30,11 @@ fn main() -> CliResult {
         return Ok(());
     }
 
-    config_configure(&mut config, subcommand_args)?;
+    global_context_configure(&mut config, subcommand_args)?;
 
     let mut ws = subcommand_args.workspace(&config)?;
 
     let (packages, compile_opts) = cbuild(&mut ws, &config, subcommand_args, "dev")?;
 
-    ctest(&ws, &config, subcommand_args, &packages, compile_opts)
+    ctest(&ws, subcommand_args, &packages, compile_opts)
 }
